########################################################
Notices about content attributions of third-party assets
########################################################

The copyright and trademarks of particular images, pictograms and brand names
are held by their respective owners, unless otherwise noted.

- Combustion engine innards from Daimler AG Archive
- Europatent logo and icon from `Europatent GmbH <Europatent_>`_
- Serviva logo from `Serviva GmbH <Serviva_>`_
- depa.tech logo and icon from `Moving Targets Consulting GmbH <MTC_>`_

.. _Europatent: https://www.europatent.net
.. _Serviva: http://www.serviva.com/
.. _MTC: https://mtc.berlin/

